@@ -81,12 +81,12 @@ static int data_cb(const struct nlmsghdr *nlh, void *data)
 
 int main(void)
 {
+	char buf[MNL_SOCKET_DUMP_SIZE];
+	unsigned int seq, portid;
 	struct mnl_socket *nl;
-	char buf[MNL_SOCKET_BUFFER_SIZE];
 	struct nlmsghdr *nlh;
 	struct rtgenmsg *rt;
 	int ret;
-	unsigned int seq, portid;
 
 	nlh = mnl_nlmsg_put_header(buf);
 	nlh->nlmsg_type	= RTM_GETLINK;
